# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import getgauge.messages.lsp_pb2 as lsp__pb2
import getgauge.messages.messages_pb2 as messages__pb2


class lspServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetStepNames = channel.unary_unary(
        '/gauge.messages.lspService/GetStepNames',
        request_serializer=messages__pb2.StepNamesRequest.SerializeToString,
        response_deserializer=messages__pb2.StepNamesResponse.FromString,
        )
    self.CacheFile = channel.unary_unary(
        '/gauge.messages.lspService/CacheFile',
        request_serializer=messages__pb2.CacheFileRequest.SerializeToString,
        response_deserializer=lsp__pb2.Empty.FromString,
        )
    self.GetStepPositions = channel.unary_unary(
        '/gauge.messages.lspService/GetStepPositions',
        request_serializer=messages__pb2.StepPositionsRequest.SerializeToString,
        response_deserializer=messages__pb2.StepPositionsResponse.FromString,
        )
    self.GetImplementationFiles = channel.unary_unary(
        '/gauge.messages.lspService/GetImplementationFiles',
        request_serializer=lsp__pb2.Empty.SerializeToString,
        response_deserializer=messages__pb2.ImplementationFileListResponse.FromString,
        )
    self.ImplementStub = channel.unary_unary(
        '/gauge.messages.lspService/ImplementStub',
        request_serializer=messages__pb2.StubImplementationCodeRequest.SerializeToString,
        response_deserializer=messages__pb2.FileDiff.FromString,
        )
    self.ValidateStep = channel.unary_unary(
        '/gauge.messages.lspService/ValidateStep',
        request_serializer=messages__pb2.StepValidateRequest.SerializeToString,
        response_deserializer=messages__pb2.StepValidateResponse.FromString,
        )
    self.Refactor = channel.unary_unary(
        '/gauge.messages.lspService/Refactor',
        request_serializer=messages__pb2.RefactorRequest.SerializeToString,
        response_deserializer=messages__pb2.RefactorResponse.FromString,
        )
    self.GetStepName = channel.unary_unary(
        '/gauge.messages.lspService/GetStepName',
        request_serializer=messages__pb2.StepNameRequest.SerializeToString,
        response_deserializer=messages__pb2.StepNameResponse.FromString,
        )
    self.GetGlobPatterns = channel.unary_unary(
        '/gauge.messages.lspService/GetGlobPatterns',
        request_serializer=lsp__pb2.Empty.SerializeToString,
        response_deserializer=messages__pb2.ImplementationFileGlobPatternResponse.FromString,
        )
    self.KillProcess = channel.unary_unary(
        '/gauge.messages.lspService/KillProcess',
        request_serializer=messages__pb2.KillProcessRequest.SerializeToString,
        response_deserializer=lsp__pb2.Empty.FromString,
        )


class lspServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetStepNames(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CacheFile(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStepPositions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetImplementationFiles(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ImplementStub(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ValidateStep(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Refactor(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStepName(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetGlobPatterns(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def KillProcess(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_lspServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetStepNames': grpc.unary_unary_rpc_method_handler(
          servicer.GetStepNames,
          request_deserializer=messages__pb2.StepNamesRequest.FromString,
          response_serializer=messages__pb2.StepNamesResponse.SerializeToString,
      ),
      'CacheFile': grpc.unary_unary_rpc_method_handler(
          servicer.CacheFile,
          request_deserializer=messages__pb2.CacheFileRequest.FromString,
          response_serializer=lsp__pb2.Empty.SerializeToString,
      ),
      'GetStepPositions': grpc.unary_unary_rpc_method_handler(
          servicer.GetStepPositions,
          request_deserializer=messages__pb2.StepPositionsRequest.FromString,
          response_serializer=messages__pb2.StepPositionsResponse.SerializeToString,
      ),
      'GetImplementationFiles': grpc.unary_unary_rpc_method_handler(
          servicer.GetImplementationFiles,
          request_deserializer=lsp__pb2.Empty.FromString,
          response_serializer=messages__pb2.ImplementationFileListResponse.SerializeToString,
      ),
      'ImplementStub': grpc.unary_unary_rpc_method_handler(
          servicer.ImplementStub,
          request_deserializer=messages__pb2.StubImplementationCodeRequest.FromString,
          response_serializer=messages__pb2.FileDiff.SerializeToString,
      ),
      'ValidateStep': grpc.unary_unary_rpc_method_handler(
          servicer.ValidateStep,
          request_deserializer=messages__pb2.StepValidateRequest.FromString,
          response_serializer=messages__pb2.StepValidateResponse.SerializeToString,
      ),
      'Refactor': grpc.unary_unary_rpc_method_handler(
          servicer.Refactor,
          request_deserializer=messages__pb2.RefactorRequest.FromString,
          response_serializer=messages__pb2.RefactorResponse.SerializeToString,
      ),
      'GetStepName': grpc.unary_unary_rpc_method_handler(
          servicer.GetStepName,
          request_deserializer=messages__pb2.StepNameRequest.FromString,
          response_serializer=messages__pb2.StepNameResponse.SerializeToString,
      ),
      'GetGlobPatterns': grpc.unary_unary_rpc_method_handler(
          servicer.GetGlobPatterns,
          request_deserializer=lsp__pb2.Empty.FromString,
          response_serializer=messages__pb2.ImplementationFileGlobPatternResponse.SerializeToString,
      ),
      'KillProcess': grpc.unary_unary_rpc_method_handler(
          servicer.KillProcess,
          request_deserializer=messages__pb2.KillProcessRequest.FromString,
          response_serializer=lsp__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'gauge.messages.lspService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
