# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import getgauge.messages.spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='gauge.messages',
  syntax='proto3',
  serialized_pb=_b('\n\x0emessages.proto\x12\x0egauge.messages\x1a\nspec.proto\"\x14\n\x12KillProcessRequest\"X\n\x17\x45xecutionStatusResponse\x12=\n\x0f\x65xecutionResult\x18\x01 \x01(\x0b\x32$.gauge.messages.ProtoExecutionResult\"W\n\x18\x45xecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"U\n\x16\x45xecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"[\n\x1cSpecExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"Y\n\x1aSpecExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"_\n ScenarioExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"]\n\x1eScenarioExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"[\n\x1cStepExecutionStartingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"Y\n\x1aStepExecutionEndingRequest\x12;\n\x14\x63urrentExecutionInfo\x18\x01 \x01(\x0b\x32\x1d.gauge.messages.ExecutionInfo\"\xb8\x01\n\rExecutionInfo\x12-\n\x0b\x63urrentSpec\x18\x01 \x01(\x0b\x32\x18.gauge.messages.SpecInfo\x12\x35\n\x0f\x63urrentScenario\x18\x02 \x01(\x0b\x32\x1c.gauge.messages.ScenarioInfo\x12-\n\x0b\x63urrentStep\x18\x03 \x01(\x0b\x32\x18.gauge.messages.StepInfo\x12\x12\n\nstacktrace\x18\x04 \x01(\t\"J\n\x08SpecInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x12\x10\n\x08isFailed\x18\x03 \x01(\x08\x12\x0c\n\x04tags\x18\x04 \x03(\t\"<\n\x0cScenarioInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08isFailed\x18\x02 \x01(\x08\x12\x0c\n\x04tags\x18\x03 \x03(\t\"x\n\x08StepInfo\x12\x30\n\x04step\x18\x01 \x01(\x0b\x32\".gauge.messages.ExecuteStepRequest\x12\x10\n\x08isFailed\x18\x02 \x01(\x08\x12\x12\n\nstackTrace\x18\x03 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x04 \x01(\t\"\x8c\x01\n\x12\x45xecuteStepRequest\x12\x16\n\x0e\x61\x63tualStepText\x18\x01 \x01(\t\x12\x16\n\x0eparsedStepText\x18\x02 \x01(\t\x12\x17\n\x0fscenarioFailing\x18\x03 \x01(\x08\x12-\n\nparameters\x18\x04 \x03(\x0b\x32\x19.gauge.messages.Parameter\"v\n\x13StepValidateRequest\x12\x10\n\x08stepText\x18\x01 \x01(\t\x12\x1a\n\x12numberOfParameters\x18\x02 \x01(\x05\x12\x31\n\tstepValue\x18\x03 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\"\xe7\x01\n\x14StepValidateResponse\x12\x0f\n\x07isValid\x18\x01 \x01(\x08\x12\x14\n\x0c\x65rrorMessage\x18\x02 \x01(\t\x12\x41\n\terrorType\x18\x03 \x01(\x0e\x32..gauge.messages.StepValidateResponse.ErrorType\x12\x12\n\nsuggestion\x18\x04 \x01(\t\"Q\n\tErrorType\x12!\n\x1dSTEP_IMPLEMENTATION_NOT_FOUND\x10\x00\x12!\n\x1d\x44UPLICATE_STEP_IMPLEMENTATION\x10\x01\"M\n\x14SuiteExecutionResult\x12\x35\n\x0bsuiteResult\x18\x01 \x01(\x0b\x32 .gauge.messages.ProtoSuiteResult\"\x12\n\x10StepNamesRequest\"\"\n\x11StepNamesResponse\x12\r\n\x05steps\x18\x01 \x03(\t\"\x1e\n\x1cScenarioDataStoreInitRequest\"\x1a\n\x18SpecDataStoreInitRequest\"\x1b\n\x19SuiteDataStoreInitRequest\"=\n\x11ParameterPosition\x12\x13\n\x0boldPosition\x18\x01 \x01(\x05\x12\x13\n\x0bnewPosition\x18\x02 \x01(\x05\"\xcd\x01\n\x0fRefactorRequest\x12\x34\n\x0coldStepValue\x18\x01 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\x12\x34\n\x0cnewStepValue\x18\x02 \x01(\x0b\x32\x1e.gauge.messages.ProtoStepValue\x12\x39\n\x0eparamPositions\x18\x03 \x03(\x0b\x32!.gauge.messages.ParameterPosition\x12\x13\n\x0bsaveChanges\x18\x04 \x01(\x08\"a\n\x0b\x46ileChanges\x12\x10\n\x08\x66ileName\x18\x01 \x01(\t\x12\x17\n\x0b\x66ileContent\x18\x02 \x01(\tB\x02\x18\x01\x12\'\n\x05\x64iffs\x18\x03 \x03(\x0b\x32\x18.gauge.messages.TextDiff\"z\n\x10RefactorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x14\n\x0c\x66ilesChanged\x18\x03 \x03(\t\x12\x30\n\x0b\x66ileChanges\x18\x04 \x03(\x0b\x32\x1b.gauge.messages.FileChanges\"$\n\x0fStepNameRequest\x12\x11\n\tstepValue\x18\x01 \x01(\t\"\x83\x01\n\x10StepNameResponse\x12\x15\n\risStepPresent\x18\x01 \x01(\x08\x12\x10\n\x08stepName\x18\x02 \x03(\t\x12\x10\n\x08hasAlias\x18\x03 \x01(\x08\x12\x10\n\x08\x66ileName\x18\x04 \x01(\t\x12\"\n\x04span\x18\x05 \x01(\x0b\x32\x14.gauge.messages.Span\"-\n\x1aUnsupportedMessageResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xd1\x01\n\x10\x43\x61\x63heFileRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x10\n\x08\x66ilePath\x18\x02 \x01(\t\x12\x10\n\x08isClosed\x18\x03 \x01(\x08\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.gauge.messages.CacheFileRequest.FileStatus\"K\n\nFileStatus\x12\x0b\n\x07\x43HANGED\x10\x00\x12\n\n\x06\x43LOSED\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x12\n\n\x06OPENED\x10\x04\"(\n\x14StepPositionsRequest\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\"\xb8\x01\n\x15StepPositionsResponse\x12I\n\rstepPositions\x18\x01 \x03(\x0b\x32\x32.gauge.messages.StepPositionsResponse.StepPosition\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x1a\x45\n\x0cStepPosition\x12\x11\n\tstepValue\x18\x01 \x01(\t\x12\"\n\x04span\x18\x02 \x01(\x0b\x32\x14.gauge.messages.Span\"&\n$ImplementationFileGlobPatternRequest\"=\n%ImplementationFileGlobPatternResponse\x12\x14\n\x0cglobPatterns\x18\x01 \x03(\t\"\x1f\n\x1dImplementationFileListRequest\"A\n\x1eImplementationFileListResponse\x12\x1f\n\x17implementationFilePaths\x18\x01 \x03(\t\"N\n\x1dStubImplementationCodeRequest\x12\x1e\n\x16implementationFilePath\x18\x01 \x01(\t\x12\r\n\x05\x63odes\x18\x02 \x03(\t\"?\n\x08TextDiff\x12\"\n\x04span\x18\x01 \x01(\x0b\x32\x14.gauge.messages.Span\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"I\n\x08\x46ileDiff\x12\x10\n\x08\x66ilePath\x18\x01 \x01(\t\x12+\n\ttextDiffs\x18\x02 \x03(\x0b\x32\x18.gauge.messages.TextDiff\"\xd6\x1a\n\x07Message\x12\x38\n\x0bmessageType\x18\x01 \x01(\x0e\x32#.gauge.messages.Message.MessageType\x12\x11\n\tmessageId\x18\x02 \x01(\x03\x12J\n\x18\x65xecutionStartingRequest\x18\x03 \x01(\x0b\x32(.gauge.messages.ExecutionStartingRequest\x12R\n\x1cspecExecutionStartingRequest\x18\x04 \x01(\x0b\x32,.gauge.messages.SpecExecutionStartingRequest\x12N\n\x1aspecExecutionEndingRequest\x18\x05 \x01(\x0b\x32*.gauge.messages.SpecExecutionEndingRequest\x12Z\n scenarioExecutionStartingRequest\x18\x06 \x01(\x0b\x32\x30.gauge.messages.ScenarioExecutionStartingRequest\x12V\n\x1escenarioExecutionEndingRequest\x18\x07 \x01(\x0b\x32..gauge.messages.ScenarioExecutionEndingRequest\x12R\n\x1cstepExecutionStartingRequest\x18\x08 \x01(\x0b\x32,.gauge.messages.StepExecutionStartingRequest\x12N\n\x1astepExecutionEndingRequest\x18\t \x01(\x0b\x32*.gauge.messages.StepExecutionEndingRequest\x12>\n\x12\x65xecuteStepRequest\x18\n \x01(\x0b\x32\".gauge.messages.ExecuteStepRequest\x12\x46\n\x16\x65xecutionEndingRequest\x18\x0b \x01(\x0b\x32&.gauge.messages.ExecutionEndingRequest\x12@\n\x13stepValidateRequest\x18\x0c \x01(\x0b\x32#.gauge.messages.StepValidateRequest\x12\x42\n\x14stepValidateResponse\x18\r \x01(\x0b\x32$.gauge.messages.StepValidateResponse\x12H\n\x17\x65xecutionStatusResponse\x18\x0e \x01(\x0b\x32\'.gauge.messages.ExecutionStatusResponse\x12:\n\x10stepNamesRequest\x18\x0f \x01(\x0b\x32 .gauge.messages.StepNamesRequest\x12<\n\x11stepNamesResponse\x18\x10 \x01(\x0b\x32!.gauge.messages.StepNamesResponse\x12\x42\n\x14suiteExecutionResult\x18\x11 \x01(\x0b\x32$.gauge.messages.SuiteExecutionResult\x12>\n\x12killProcessRequest\x18\x12 \x01(\x0b\x32\".gauge.messages.KillProcessRequest\x12R\n\x1cscenarioDataStoreInitRequest\x18\x13 \x01(\x0b\x32,.gauge.messages.ScenarioDataStoreInitRequest\x12J\n\x18specDataStoreInitRequest\x18\x14 \x01(\x0b\x32(.gauge.messages.SpecDataStoreInitRequest\x12L\n\x19suiteDataStoreInitRequest\x18\x15 \x01(\x0b\x32).gauge.messages.SuiteDataStoreInitRequest\x12\x38\n\x0fstepNameRequest\x18\x16 \x01(\x0b\x32\x1f.gauge.messages.StepNameRequest\x12:\n\x10stepNameResponse\x18\x17 \x01(\x0b\x32 .gauge.messages.StepNameResponse\x12\x38\n\x0frefactorRequest\x18\x18 \x01(\x0b\x32\x1f.gauge.messages.RefactorRequest\x12:\n\x10refactorResponse\x18\x19 \x01(\x0b\x32 .gauge.messages.RefactorResponse\x12N\n\x1aunsupportedMessageResponse\x18\x1a \x01(\x0b\x32*.gauge.messages.UnsupportedMessageResponse\x12:\n\x10\x63\x61\x63heFileRequest\x18\x1b \x01(\x0b\x32 .gauge.messages.CacheFileRequest\x12\x42\n\x14stepPositionsRequest\x18\x1c \x01(\x0b\x32$.gauge.messages.StepPositionsRequest\x12\x44\n\x15stepPositionsResponse\x18\x1d \x01(\x0b\x32%.gauge.messages.StepPositionsResponse\x12T\n\x1dimplementationFileListRequest\x18\x1e \x01(\x0b\x32-.gauge.messages.ImplementationFileListRequest\x12V\n\x1eimplementationFileListResponse\x18\x1f \x01(\x0b\x32..gauge.messages.ImplementationFileListResponse\x12T\n\x1dstubImplementationCodeRequest\x18  \x01(\x0b\x32-.gauge.messages.StubImplementationCodeRequest\x12*\n\x08\x66ileDiff\x18! \x01(\x0b\x32\x18.gauge.messages.FileDiff\x12\x62\n$implementationFileGlobPatternRequest\x18\" \x01(\x0b\x32\x34.gauge.messages.ImplementationFileGlobPatternRequest\x12\x64\n%implementationFileGlobPatternResponse\x18# \x01(\x0b\x32\x35.gauge.messages.ImplementationFileGlobPatternResponse\"\xf5\x06\n\x0bMessageType\x12\x15\n\x11\x45xecutionStarting\x10\x00\x12\x19\n\x15SpecExecutionStarting\x10\x01\x12\x17\n\x13SpecExecutionEnding\x10\x02\x12\x1d\n\x19ScenarioExecutionStarting\x10\x03\x12\x1b\n\x17ScenarioExecutionEnding\x10\x04\x12\x19\n\x15StepExecutionStarting\x10\x05\x12\x17\n\x13StepExecutionEnding\x10\x06\x12\x0f\n\x0b\x45xecuteStep\x10\x07\x12\x13\n\x0f\x45xecutionEnding\x10\x08\x12\x17\n\x13StepValidateRequest\x10\t\x12\x18\n\x14StepValidateResponse\x10\n\x12\x1b\n\x17\x45xecutionStatusResponse\x10\x0b\x12\x14\n\x10StepNamesRequest\x10\x0c\x12\x15\n\x11StepNamesResponse\x10\r\x12\x16\n\x12KillProcessRequest\x10\x0e\x12\x18\n\x14SuiteExecutionResult\x10\x0f\x12\x19\n\x15ScenarioDataStoreInit\x10\x10\x12\x15\n\x11SpecDataStoreInit\x10\x11\x12\x16\n\x12SuiteDataStoreInit\x10\x12\x12\x13\n\x0fStepNameRequest\x10\x13\x12\x14\n\x10StepNameResponse\x10\x14\x12\x13\n\x0fRefactorRequest\x10\x15\x12\x14\n\x10RefactorResponse\x10\x16\x12\x1e\n\x1aUnsupportedMessageResponse\x10\x17\x12\x14\n\x10\x43\x61\x63heFileRequest\x10\x18\x12\x18\n\x14StepPositionsRequest\x10\x19\x12\x19\n\x15StepPositionsResponse\x10\x1a\x12!\n\x1dImplementationFileListRequest\x10\x1b\x12\"\n\x1eImplementationFileListResponse\x10\x1c\x12!\n\x1dStubImplementationCodeRequest\x10\x1d\x12\x0c\n\x08\x46ileDiff\x10\x1e\x12(\n$ImplementationFileGlobPatternRequest\x10\x1f\x12)\n%ImplementationFileGlobPatternResponse\x10 B)\n\x16\x63om.thoughtworks.gauge\xaa\x02\x0eGauge.Messagesb\x06proto3')
  ,
  dependencies=[spec__pb2.DESCRIPTOR,])



_STEPVALIDATERESPONSE_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='gauge.messages.StepValidateResponse.ErrorType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STEP_IMPLEMENTATION_NOT_FOUND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_STEP_IMPLEMENTATION', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1755,
  serialized_end=1836,
)
_sym_db.RegisterEnumDescriptor(_STEPVALIDATERESPONSE_ERRORTYPE)

_CACHEFILEREQUEST_FILESTATUS = _descriptor.EnumDescriptor(
  name='FileStatus',
  full_name='gauge.messages.CacheFileRequest.FileStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHANGED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPENED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2910,
  serialized_end=2985,
)
_sym_db.RegisterEnumDescriptor(_CACHEFILEREQUEST_FILESTATUS)

_MESSAGE_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='gauge.messages.Message.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ExecutionStarting', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpecExecutionStarting', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpecExecutionEnding', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ScenarioExecutionStarting', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ScenarioExecutionEnding', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepExecutionStarting', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepExecutionEnding', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecuteStep', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecutionEnding', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepValidateRequest', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepValidateResponse', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ExecutionStatusResponse', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepNamesRequest', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepNamesResponse', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KillProcessRequest', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SuiteExecutionResult', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ScenarioDataStoreInit', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpecDataStoreInit', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SuiteDataStoreInit', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepNameRequest', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepNameResponse', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RefactorRequest', index=21, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RefactorResponse', index=22, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UnsupportedMessageResponse', index=23, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CacheFileRequest', index=24, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepPositionsRequest', index=25, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StepPositionsResponse', index=26, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImplementationFileListRequest', index=27, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImplementationFileListResponse', index=28, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StubImplementationCodeRequest', index=29, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FileDiff', index=30, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImplementationFileGlobPatternRequest', index=31, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImplementationFileGlobPatternResponse', index=32, number=32,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=6169,
  serialized_end=7054,
)
_sym_db.RegisterEnumDescriptor(_MESSAGE_MESSAGETYPE)


_KILLPROCESSREQUEST = _descriptor.Descriptor(
  name='KillProcessRequest',
  full_name='gauge.messages.KillProcessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=66,
)


_EXECUTIONSTATUSRESPONSE = _descriptor.Descriptor(
  name='ExecutionStatusResponse',
  full_name='gauge.messages.ExecutionStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executionResult', full_name='gauge.messages.ExecutionStatusResponse.executionResult', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=156,
)


_EXECUTIONSTARTINGREQUEST = _descriptor.Descriptor(
  name='ExecutionStartingRequest',
  full_name='gauge.messages.ExecutionStartingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.ExecutionStartingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=245,
)


_EXECUTIONENDINGREQUEST = _descriptor.Descriptor(
  name='ExecutionEndingRequest',
  full_name='gauge.messages.ExecutionEndingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.ExecutionEndingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=332,
)


_SPECEXECUTIONSTARTINGREQUEST = _descriptor.Descriptor(
  name='SpecExecutionStartingRequest',
  full_name='gauge.messages.SpecExecutionStartingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.SpecExecutionStartingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=425,
)


_SPECEXECUTIONENDINGREQUEST = _descriptor.Descriptor(
  name='SpecExecutionEndingRequest',
  full_name='gauge.messages.SpecExecutionEndingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.SpecExecutionEndingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=516,
)


_SCENARIOEXECUTIONSTARTINGREQUEST = _descriptor.Descriptor(
  name='ScenarioExecutionStartingRequest',
  full_name='gauge.messages.ScenarioExecutionStartingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.ScenarioExecutionStartingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=613,
)


_SCENARIOEXECUTIONENDINGREQUEST = _descriptor.Descriptor(
  name='ScenarioExecutionEndingRequest',
  full_name='gauge.messages.ScenarioExecutionEndingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.ScenarioExecutionEndingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=708,
)


_STEPEXECUTIONSTARTINGREQUEST = _descriptor.Descriptor(
  name='StepExecutionStartingRequest',
  full_name='gauge.messages.StepExecutionStartingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.StepExecutionStartingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=801,
)


_STEPEXECUTIONENDINGREQUEST = _descriptor.Descriptor(
  name='StepExecutionEndingRequest',
  full_name='gauge.messages.StepExecutionEndingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentExecutionInfo', full_name='gauge.messages.StepExecutionEndingRequest.currentExecutionInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=892,
)


_EXECUTIONINFO = _descriptor.Descriptor(
  name='ExecutionInfo',
  full_name='gauge.messages.ExecutionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentSpec', full_name='gauge.messages.ExecutionInfo.currentSpec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentScenario', full_name='gauge.messages.ExecutionInfo.currentScenario', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currentStep', full_name='gauge.messages.ExecutionInfo.currentStep', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stacktrace', full_name='gauge.messages.ExecutionInfo.stacktrace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=1079,
)


_SPECINFO = _descriptor.Descriptor(
  name='SpecInfo',
  full_name='gauge.messages.SpecInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gauge.messages.SpecInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='gauge.messages.SpecInfo.fileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFailed', full_name='gauge.messages.SpecInfo.isFailed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.SpecInfo.tags', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1155,
)


_SCENARIOINFO = _descriptor.Descriptor(
  name='ScenarioInfo',
  full_name='gauge.messages.ScenarioInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gauge.messages.ScenarioInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFailed', full_name='gauge.messages.ScenarioInfo.isFailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='gauge.messages.ScenarioInfo.tags', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1217,
)


_STEPINFO = _descriptor.Descriptor(
  name='StepInfo',
  full_name='gauge.messages.StepInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='step', full_name='gauge.messages.StepInfo.step', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFailed', full_name='gauge.messages.StepInfo.isFailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stackTrace', full_name='gauge.messages.StepInfo.stackTrace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gauge.messages.StepInfo.errorMessage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1339,
)


_EXECUTESTEPREQUEST = _descriptor.Descriptor(
  name='ExecuteStepRequest',
  full_name='gauge.messages.ExecuteStepRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='actualStepText', full_name='gauge.messages.ExecuteStepRequest.actualStepText', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parsedStepText', full_name='gauge.messages.ExecuteStepRequest.parsedStepText', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioFailing', full_name='gauge.messages.ExecuteStepRequest.scenarioFailing', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='gauge.messages.ExecuteStepRequest.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1482,
)


_STEPVALIDATEREQUEST = _descriptor.Descriptor(
  name='StepValidateRequest',
  full_name='gauge.messages.StepValidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepText', full_name='gauge.messages.StepValidateRequest.stepText', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfParameters', full_name='gauge.messages.StepValidateRequest.numberOfParameters', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.StepValidateRequest.stepValue', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1602,
)


_STEPVALIDATERESPONSE = _descriptor.Descriptor(
  name='StepValidateResponse',
  full_name='gauge.messages.StepValidateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isValid', full_name='gauge.messages.StepValidateResponse.isValid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gauge.messages.StepValidateResponse.errorMessage', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorType', full_name='gauge.messages.StepValidateResponse.errorType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suggestion', full_name='gauge.messages.StepValidateResponse.suggestion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STEPVALIDATERESPONSE_ERRORTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1605,
  serialized_end=1836,
)


_SUITEEXECUTIONRESULT = _descriptor.Descriptor(
  name='SuiteExecutionResult',
  full_name='gauge.messages.SuiteExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='suiteResult', full_name='gauge.messages.SuiteExecutionResult.suiteResult', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1838,
  serialized_end=1915,
)


_STEPNAMESREQUEST = _descriptor.Descriptor(
  name='StepNamesRequest',
  full_name='gauge.messages.StepNamesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1917,
  serialized_end=1935,
)


_STEPNAMESRESPONSE = _descriptor.Descriptor(
  name='StepNamesResponse',
  full_name='gauge.messages.StepNamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='gauge.messages.StepNamesResponse.steps', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1937,
  serialized_end=1971,
)


_SCENARIODATASTOREINITREQUEST = _descriptor.Descriptor(
  name='ScenarioDataStoreInitRequest',
  full_name='gauge.messages.ScenarioDataStoreInitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2003,
)


_SPECDATASTOREINITREQUEST = _descriptor.Descriptor(
  name='SpecDataStoreInitRequest',
  full_name='gauge.messages.SpecDataStoreInitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2031,
)


_SUITEDATASTOREINITREQUEST = _descriptor.Descriptor(
  name='SuiteDataStoreInitRequest',
  full_name='gauge.messages.SuiteDataStoreInitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2033,
  serialized_end=2060,
)


_PARAMETERPOSITION = _descriptor.Descriptor(
  name='ParameterPosition',
  full_name='gauge.messages.ParameterPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldPosition', full_name='gauge.messages.ParameterPosition.oldPosition', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newPosition', full_name='gauge.messages.ParameterPosition.newPosition', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2123,
)


_REFACTORREQUEST = _descriptor.Descriptor(
  name='RefactorRequest',
  full_name='gauge.messages.RefactorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oldStepValue', full_name='gauge.messages.RefactorRequest.oldStepValue', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newStepValue', full_name='gauge.messages.RefactorRequest.newStepValue', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paramPositions', full_name='gauge.messages.RefactorRequest.paramPositions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saveChanges', full_name='gauge.messages.RefactorRequest.saveChanges', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2126,
  serialized_end=2331,
)


_FILECHANGES = _descriptor.Descriptor(
  name='FileChanges',
  full_name='gauge.messages.FileChanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileName', full_name='gauge.messages.FileChanges.fileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileContent', full_name='gauge.messages.FileChanges.fileContent', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='diffs', full_name='gauge.messages.FileChanges.diffs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2333,
  serialized_end=2430,
)


_REFACTORRESPONSE = _descriptor.Descriptor(
  name='RefactorResponse',
  full_name='gauge.messages.RefactorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='gauge.messages.RefactorResponse.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='gauge.messages.RefactorResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filesChanged', full_name='gauge.messages.RefactorResponse.filesChanged', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileChanges', full_name='gauge.messages.RefactorResponse.fileChanges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2432,
  serialized_end=2554,
)


_STEPNAMEREQUEST = _descriptor.Descriptor(
  name='StepNameRequest',
  full_name='gauge.messages.StepNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.StepNameRequest.stepValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2592,
)


_STEPNAMERESPONSE = _descriptor.Descriptor(
  name='StepNameResponse',
  full_name='gauge.messages.StepNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isStepPresent', full_name='gauge.messages.StepNameResponse.isStepPresent', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepName', full_name='gauge.messages.StepNameResponse.stepName', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hasAlias', full_name='gauge.messages.StepNameResponse.hasAlias', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='gauge.messages.StepNameResponse.fileName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span', full_name='gauge.messages.StepNameResponse.span', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2726,
)


_UNSUPPORTEDMESSAGERESPONSE = _descriptor.Descriptor(
  name='UnsupportedMessageResponse',
  full_name='gauge.messages.UnsupportedMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='gauge.messages.UnsupportedMessageResponse.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2728,
  serialized_end=2773,
)


_CACHEFILEREQUEST = _descriptor.Descriptor(
  name='CacheFileRequest',
  full_name='gauge.messages.CacheFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='gauge.messages.CacheFileRequest.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filePath', full_name='gauge.messages.CacheFileRequest.filePath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isClosed', full_name='gauge.messages.CacheFileRequest.isClosed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='gauge.messages.CacheFileRequest.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CACHEFILEREQUEST_FILESTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2776,
  serialized_end=2985,
)


_STEPPOSITIONSREQUEST = _descriptor.Descriptor(
  name='StepPositionsRequest',
  full_name='gauge.messages.StepPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filePath', full_name='gauge.messages.StepPositionsRequest.filePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2987,
  serialized_end=3027,
)


_STEPPOSITIONSRESPONSE_STEPPOSITION = _descriptor.Descriptor(
  name='StepPosition',
  full_name='gauge.messages.StepPositionsResponse.StepPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepValue', full_name='gauge.messages.StepPositionsResponse.StepPosition.stepValue', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='span', full_name='gauge.messages.StepPositionsResponse.StepPosition.span', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3145,
  serialized_end=3214,
)

_STEPPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='StepPositionsResponse',
  full_name='gauge.messages.StepPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stepPositions', full_name='gauge.messages.StepPositionsResponse.stepPositions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='gauge.messages.StepPositionsResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STEPPOSITIONSRESPONSE_STEPPOSITION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3030,
  serialized_end=3214,
)


_IMPLEMENTATIONFILEGLOBPATTERNREQUEST = _descriptor.Descriptor(
  name='ImplementationFileGlobPatternRequest',
  full_name='gauge.messages.ImplementationFileGlobPatternRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3216,
  serialized_end=3254,
)


_IMPLEMENTATIONFILEGLOBPATTERNRESPONSE = _descriptor.Descriptor(
  name='ImplementationFileGlobPatternResponse',
  full_name='gauge.messages.ImplementationFileGlobPatternResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='globPatterns', full_name='gauge.messages.ImplementationFileGlobPatternResponse.globPatterns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3256,
  serialized_end=3317,
)


_IMPLEMENTATIONFILELISTREQUEST = _descriptor.Descriptor(
  name='ImplementationFileListRequest',
  full_name='gauge.messages.ImplementationFileListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3319,
  serialized_end=3350,
)


_IMPLEMENTATIONFILELISTRESPONSE = _descriptor.Descriptor(
  name='ImplementationFileListResponse',
  full_name='gauge.messages.ImplementationFileListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='implementationFilePaths', full_name='gauge.messages.ImplementationFileListResponse.implementationFilePaths', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3352,
  serialized_end=3417,
)


_STUBIMPLEMENTATIONCODEREQUEST = _descriptor.Descriptor(
  name='StubImplementationCodeRequest',
  full_name='gauge.messages.StubImplementationCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='implementationFilePath', full_name='gauge.messages.StubImplementationCodeRequest.implementationFilePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='codes', full_name='gauge.messages.StubImplementationCodeRequest.codes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3419,
  serialized_end=3497,
)


_TEXTDIFF = _descriptor.Descriptor(
  name='TextDiff',
  full_name='gauge.messages.TextDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='span', full_name='gauge.messages.TextDiff.span', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='gauge.messages.TextDiff.content', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3499,
  serialized_end=3562,
)


_FILEDIFF = _descriptor.Descriptor(
  name='FileDiff',
  full_name='gauge.messages.FileDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filePath', full_name='gauge.messages.FileDiff.filePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='textDiffs', full_name='gauge.messages.FileDiff.textDiffs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3564,
  serialized_end=3637,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='gauge.messages.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messageType', full_name='gauge.messages.Message.messageType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messageId', full_name='gauge.messages.Message.messageId', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionStartingRequest', full_name='gauge.messages.Message.executionStartingRequest', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specExecutionStartingRequest', full_name='gauge.messages.Message.specExecutionStartingRequest', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specExecutionEndingRequest', full_name='gauge.messages.Message.specExecutionEndingRequest', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioExecutionStartingRequest', full_name='gauge.messages.Message.scenarioExecutionStartingRequest', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioExecutionEndingRequest', full_name='gauge.messages.Message.scenarioExecutionEndingRequest', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepExecutionStartingRequest', full_name='gauge.messages.Message.stepExecutionStartingRequest', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepExecutionEndingRequest', full_name='gauge.messages.Message.stepExecutionEndingRequest', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executeStepRequest', full_name='gauge.messages.Message.executeStepRequest', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionEndingRequest', full_name='gauge.messages.Message.executionEndingRequest', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepValidateRequest', full_name='gauge.messages.Message.stepValidateRequest', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepValidateResponse', full_name='gauge.messages.Message.stepValidateResponse', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='executionStatusResponse', full_name='gauge.messages.Message.executionStatusResponse', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepNamesRequest', full_name='gauge.messages.Message.stepNamesRequest', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepNamesResponse', full_name='gauge.messages.Message.stepNamesResponse', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suiteExecutionResult', full_name='gauge.messages.Message.suiteExecutionResult', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='killProcessRequest', full_name='gauge.messages.Message.killProcessRequest', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scenarioDataStoreInitRequest', full_name='gauge.messages.Message.scenarioDataStoreInitRequest', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specDataStoreInitRequest', full_name='gauge.messages.Message.specDataStoreInitRequest', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suiteDataStoreInitRequest', full_name='gauge.messages.Message.suiteDataStoreInitRequest', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepNameRequest', full_name='gauge.messages.Message.stepNameRequest', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepNameResponse', full_name='gauge.messages.Message.stepNameResponse', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refactorRequest', full_name='gauge.messages.Message.refactorRequest', index=23,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refactorResponse', full_name='gauge.messages.Message.refactorResponse', index=24,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsupportedMessageResponse', full_name='gauge.messages.Message.unsupportedMessageResponse', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cacheFileRequest', full_name='gauge.messages.Message.cacheFileRequest', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepPositionsRequest', full_name='gauge.messages.Message.stepPositionsRequest', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stepPositionsResponse', full_name='gauge.messages.Message.stepPositionsResponse', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationFileListRequest', full_name='gauge.messages.Message.implementationFileListRequest', index=29,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationFileListResponse', full_name='gauge.messages.Message.implementationFileListResponse', index=30,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stubImplementationCodeRequest', full_name='gauge.messages.Message.stubImplementationCodeRequest', index=31,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileDiff', full_name='gauge.messages.Message.fileDiff', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationFileGlobPatternRequest', full_name='gauge.messages.Message.implementationFileGlobPatternRequest', index=33,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationFileGlobPatternResponse', full_name='gauge.messages.Message.implementationFileGlobPatternResponse', index=34,
      number=35, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MESSAGE_MESSAGETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3640,
  serialized_end=7054,
)

_EXECUTIONSTATUSRESPONSE.fields_by_name['executionResult'].message_type = spec__pb2._PROTOEXECUTIONRESULT
_EXECUTIONSTARTINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_EXECUTIONENDINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_SPECEXECUTIONSTARTINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_SPECEXECUTIONENDINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_SCENARIOEXECUTIONSTARTINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_SCENARIOEXECUTIONENDINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_STEPEXECUTIONSTARTINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_STEPEXECUTIONENDINGREQUEST.fields_by_name['currentExecutionInfo'].message_type = _EXECUTIONINFO
_EXECUTIONINFO.fields_by_name['currentSpec'].message_type = _SPECINFO
_EXECUTIONINFO.fields_by_name['currentScenario'].message_type = _SCENARIOINFO
_EXECUTIONINFO.fields_by_name['currentStep'].message_type = _STEPINFO
_STEPINFO.fields_by_name['step'].message_type = _EXECUTESTEPREQUEST
_EXECUTESTEPREQUEST.fields_by_name['parameters'].message_type = spec__pb2._PARAMETER
_STEPVALIDATEREQUEST.fields_by_name['stepValue'].message_type = spec__pb2._PROTOSTEPVALUE
_STEPVALIDATERESPONSE.fields_by_name['errorType'].enum_type = _STEPVALIDATERESPONSE_ERRORTYPE
_STEPVALIDATERESPONSE_ERRORTYPE.containing_type = _STEPVALIDATERESPONSE
_SUITEEXECUTIONRESULT.fields_by_name['suiteResult'].message_type = spec__pb2._PROTOSUITERESULT
_REFACTORREQUEST.fields_by_name['oldStepValue'].message_type = spec__pb2._PROTOSTEPVALUE
_REFACTORREQUEST.fields_by_name['newStepValue'].message_type = spec__pb2._PROTOSTEPVALUE
_REFACTORREQUEST.fields_by_name['paramPositions'].message_type = _PARAMETERPOSITION
_FILECHANGES.fields_by_name['diffs'].message_type = _TEXTDIFF
_REFACTORRESPONSE.fields_by_name['fileChanges'].message_type = _FILECHANGES
_STEPNAMERESPONSE.fields_by_name['span'].message_type = spec__pb2._SPAN
_CACHEFILEREQUEST.fields_by_name['status'].enum_type = _CACHEFILEREQUEST_FILESTATUS
_CACHEFILEREQUEST_FILESTATUS.containing_type = _CACHEFILEREQUEST
_STEPPOSITIONSRESPONSE_STEPPOSITION.fields_by_name['span'].message_type = spec__pb2._SPAN
_STEPPOSITIONSRESPONSE_STEPPOSITION.containing_type = _STEPPOSITIONSRESPONSE
_STEPPOSITIONSRESPONSE.fields_by_name['stepPositions'].message_type = _STEPPOSITIONSRESPONSE_STEPPOSITION
_TEXTDIFF.fields_by_name['span'].message_type = spec__pb2._SPAN
_FILEDIFF.fields_by_name['textDiffs'].message_type = _TEXTDIFF
_MESSAGE.fields_by_name['messageType'].enum_type = _MESSAGE_MESSAGETYPE
_MESSAGE.fields_by_name['executionStartingRequest'].message_type = _EXECUTIONSTARTINGREQUEST
_MESSAGE.fields_by_name['specExecutionStartingRequest'].message_type = _SPECEXECUTIONSTARTINGREQUEST
_MESSAGE.fields_by_name['specExecutionEndingRequest'].message_type = _SPECEXECUTIONENDINGREQUEST
_MESSAGE.fields_by_name['scenarioExecutionStartingRequest'].message_type = _SCENARIOEXECUTIONSTARTINGREQUEST
_MESSAGE.fields_by_name['scenarioExecutionEndingRequest'].message_type = _SCENARIOEXECUTIONENDINGREQUEST
_MESSAGE.fields_by_name['stepExecutionStartingRequest'].message_type = _STEPEXECUTIONSTARTINGREQUEST
_MESSAGE.fields_by_name['stepExecutionEndingRequest'].message_type = _STEPEXECUTIONENDINGREQUEST
_MESSAGE.fields_by_name['executeStepRequest'].message_type = _EXECUTESTEPREQUEST
_MESSAGE.fields_by_name['executionEndingRequest'].message_type = _EXECUTIONENDINGREQUEST
_MESSAGE.fields_by_name['stepValidateRequest'].message_type = _STEPVALIDATEREQUEST
_MESSAGE.fields_by_name['stepValidateResponse'].message_type = _STEPVALIDATERESPONSE
_MESSAGE.fields_by_name['executionStatusResponse'].message_type = _EXECUTIONSTATUSRESPONSE
_MESSAGE.fields_by_name['stepNamesRequest'].message_type = _STEPNAMESREQUEST
_MESSAGE.fields_by_name['stepNamesResponse'].message_type = _STEPNAMESRESPONSE
_MESSAGE.fields_by_name['suiteExecutionResult'].message_type = _SUITEEXECUTIONRESULT
_MESSAGE.fields_by_name['killProcessRequest'].message_type = _KILLPROCESSREQUEST
_MESSAGE.fields_by_name['scenarioDataStoreInitRequest'].message_type = _SCENARIODATASTOREINITREQUEST
_MESSAGE.fields_by_name['specDataStoreInitRequest'].message_type = _SPECDATASTOREINITREQUEST
_MESSAGE.fields_by_name['suiteDataStoreInitRequest'].message_type = _SUITEDATASTOREINITREQUEST
_MESSAGE.fields_by_name['stepNameRequest'].message_type = _STEPNAMEREQUEST
_MESSAGE.fields_by_name['stepNameResponse'].message_type = _STEPNAMERESPONSE
_MESSAGE.fields_by_name['refactorRequest'].message_type = _REFACTORREQUEST
_MESSAGE.fields_by_name['refactorResponse'].message_type = _REFACTORRESPONSE
_MESSAGE.fields_by_name['unsupportedMessageResponse'].message_type = _UNSUPPORTEDMESSAGERESPONSE
_MESSAGE.fields_by_name['cacheFileRequest'].message_type = _CACHEFILEREQUEST
_MESSAGE.fields_by_name['stepPositionsRequest'].message_type = _STEPPOSITIONSREQUEST
_MESSAGE.fields_by_name['stepPositionsResponse'].message_type = _STEPPOSITIONSRESPONSE
_MESSAGE.fields_by_name['implementationFileListRequest'].message_type = _IMPLEMENTATIONFILELISTREQUEST
_MESSAGE.fields_by_name['implementationFileListResponse'].message_type = _IMPLEMENTATIONFILELISTRESPONSE
_MESSAGE.fields_by_name['stubImplementationCodeRequest'].message_type = _STUBIMPLEMENTATIONCODEREQUEST
_MESSAGE.fields_by_name['fileDiff'].message_type = _FILEDIFF
_MESSAGE.fields_by_name['implementationFileGlobPatternRequest'].message_type = _IMPLEMENTATIONFILEGLOBPATTERNREQUEST
_MESSAGE.fields_by_name['implementationFileGlobPatternResponse'].message_type = _IMPLEMENTATIONFILEGLOBPATTERNRESPONSE
_MESSAGE_MESSAGETYPE.containing_type = _MESSAGE
DESCRIPTOR.message_types_by_name['KillProcessRequest'] = _KILLPROCESSREQUEST
DESCRIPTOR.message_types_by_name['ExecutionStatusResponse'] = _EXECUTIONSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['ExecutionStartingRequest'] = _EXECUTIONSTARTINGREQUEST
DESCRIPTOR.message_types_by_name['ExecutionEndingRequest'] = _EXECUTIONENDINGREQUEST
DESCRIPTOR.message_types_by_name['SpecExecutionStartingRequest'] = _SPECEXECUTIONSTARTINGREQUEST
DESCRIPTOR.message_types_by_name['SpecExecutionEndingRequest'] = _SPECEXECUTIONENDINGREQUEST
DESCRIPTOR.message_types_by_name['ScenarioExecutionStartingRequest'] = _SCENARIOEXECUTIONSTARTINGREQUEST
DESCRIPTOR.message_types_by_name['ScenarioExecutionEndingRequest'] = _SCENARIOEXECUTIONENDINGREQUEST
DESCRIPTOR.message_types_by_name['StepExecutionStartingRequest'] = _STEPEXECUTIONSTARTINGREQUEST
DESCRIPTOR.message_types_by_name['StepExecutionEndingRequest'] = _STEPEXECUTIONENDINGREQUEST
DESCRIPTOR.message_types_by_name['ExecutionInfo'] = _EXECUTIONINFO
DESCRIPTOR.message_types_by_name['SpecInfo'] = _SPECINFO
DESCRIPTOR.message_types_by_name['ScenarioInfo'] = _SCENARIOINFO
DESCRIPTOR.message_types_by_name['StepInfo'] = _STEPINFO
DESCRIPTOR.message_types_by_name['ExecuteStepRequest'] = _EXECUTESTEPREQUEST
DESCRIPTOR.message_types_by_name['StepValidateRequest'] = _STEPVALIDATEREQUEST
DESCRIPTOR.message_types_by_name['StepValidateResponse'] = _STEPVALIDATERESPONSE
DESCRIPTOR.message_types_by_name['SuiteExecutionResult'] = _SUITEEXECUTIONRESULT
DESCRIPTOR.message_types_by_name['StepNamesRequest'] = _STEPNAMESREQUEST
DESCRIPTOR.message_types_by_name['StepNamesResponse'] = _STEPNAMESRESPONSE
DESCRIPTOR.message_types_by_name['ScenarioDataStoreInitRequest'] = _SCENARIODATASTOREINITREQUEST
DESCRIPTOR.message_types_by_name['SpecDataStoreInitRequest'] = _SPECDATASTOREINITREQUEST
DESCRIPTOR.message_types_by_name['SuiteDataStoreInitRequest'] = _SUITEDATASTOREINITREQUEST
DESCRIPTOR.message_types_by_name['ParameterPosition'] = _PARAMETERPOSITION
DESCRIPTOR.message_types_by_name['RefactorRequest'] = _REFACTORREQUEST
DESCRIPTOR.message_types_by_name['FileChanges'] = _FILECHANGES
DESCRIPTOR.message_types_by_name['RefactorResponse'] = _REFACTORRESPONSE
DESCRIPTOR.message_types_by_name['StepNameRequest'] = _STEPNAMEREQUEST
DESCRIPTOR.message_types_by_name['StepNameResponse'] = _STEPNAMERESPONSE
DESCRIPTOR.message_types_by_name['UnsupportedMessageResponse'] = _UNSUPPORTEDMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['CacheFileRequest'] = _CACHEFILEREQUEST
DESCRIPTOR.message_types_by_name['StepPositionsRequest'] = _STEPPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['StepPositionsResponse'] = _STEPPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['ImplementationFileGlobPatternRequest'] = _IMPLEMENTATIONFILEGLOBPATTERNREQUEST
DESCRIPTOR.message_types_by_name['ImplementationFileGlobPatternResponse'] = _IMPLEMENTATIONFILEGLOBPATTERNRESPONSE
DESCRIPTOR.message_types_by_name['ImplementationFileListRequest'] = _IMPLEMENTATIONFILELISTREQUEST
DESCRIPTOR.message_types_by_name['ImplementationFileListResponse'] = _IMPLEMENTATIONFILELISTRESPONSE
DESCRIPTOR.message_types_by_name['StubImplementationCodeRequest'] = _STUBIMPLEMENTATIONCODEREQUEST
DESCRIPTOR.message_types_by_name['TextDiff'] = _TEXTDIFF
DESCRIPTOR.message_types_by_name['FileDiff'] = _FILEDIFF
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KillProcessRequest = _reflection.GeneratedProtocolMessageType('KillProcessRequest', (_message.Message,), dict(
  DESCRIPTOR = _KILLPROCESSREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.KillProcessRequest)
  ))
_sym_db.RegisterMessage(KillProcessRequest)

ExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('ExecutionStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSTATUSRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExecutionStatusResponse)
  ))
_sym_db.RegisterMessage(ExecutionStatusResponse)

ExecutionStartingRequest = _reflection.GeneratedProtocolMessageType('ExecutionStartingRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSTARTINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExecutionStartingRequest)
  ))
_sym_db.RegisterMessage(ExecutionStartingRequest)

ExecutionEndingRequest = _reflection.GeneratedProtocolMessageType('ExecutionEndingRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONENDINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExecutionEndingRequest)
  ))
_sym_db.RegisterMessage(ExecutionEndingRequest)

SpecExecutionStartingRequest = _reflection.GeneratedProtocolMessageType('SpecExecutionStartingRequest', (_message.Message,), dict(
  DESCRIPTOR = _SPECEXECUTIONSTARTINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecExecutionStartingRequest)
  ))
_sym_db.RegisterMessage(SpecExecutionStartingRequest)

SpecExecutionEndingRequest = _reflection.GeneratedProtocolMessageType('SpecExecutionEndingRequest', (_message.Message,), dict(
  DESCRIPTOR = _SPECEXECUTIONENDINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecExecutionEndingRequest)
  ))
_sym_db.RegisterMessage(SpecExecutionEndingRequest)

ScenarioExecutionStartingRequest = _reflection.GeneratedProtocolMessageType('ScenarioExecutionStartingRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCENARIOEXECUTIONSTARTINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ScenarioExecutionStartingRequest)
  ))
_sym_db.RegisterMessage(ScenarioExecutionStartingRequest)

ScenarioExecutionEndingRequest = _reflection.GeneratedProtocolMessageType('ScenarioExecutionEndingRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCENARIOEXECUTIONENDINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ScenarioExecutionEndingRequest)
  ))
_sym_db.RegisterMessage(ScenarioExecutionEndingRequest)

StepExecutionStartingRequest = _reflection.GeneratedProtocolMessageType('StepExecutionStartingRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPEXECUTIONSTARTINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepExecutionStartingRequest)
  ))
_sym_db.RegisterMessage(StepExecutionStartingRequest)

StepExecutionEndingRequest = _reflection.GeneratedProtocolMessageType('StepExecutionEndingRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPEXECUTIONENDINGREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepExecutionEndingRequest)
  ))
_sym_db.RegisterMessage(StepExecutionEndingRequest)

ExecutionInfo = _reflection.GeneratedProtocolMessageType('ExecutionInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONINFO,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExecutionInfo)
  ))
_sym_db.RegisterMessage(ExecutionInfo)

SpecInfo = _reflection.GeneratedProtocolMessageType('SpecInfo', (_message.Message,), dict(
  DESCRIPTOR = _SPECINFO,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecInfo)
  ))
_sym_db.RegisterMessage(SpecInfo)

ScenarioInfo = _reflection.GeneratedProtocolMessageType('ScenarioInfo', (_message.Message,), dict(
  DESCRIPTOR = _SCENARIOINFO,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ScenarioInfo)
  ))
_sym_db.RegisterMessage(ScenarioInfo)

StepInfo = _reflection.GeneratedProtocolMessageType('StepInfo', (_message.Message,), dict(
  DESCRIPTOR = _STEPINFO,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepInfo)
  ))
_sym_db.RegisterMessage(StepInfo)

ExecuteStepRequest = _reflection.GeneratedProtocolMessageType('ExecuteStepRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTESTEPREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ExecuteStepRequest)
  ))
_sym_db.RegisterMessage(ExecuteStepRequest)

StepValidateRequest = _reflection.GeneratedProtocolMessageType('StepValidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPVALIDATEREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepValidateRequest)
  ))
_sym_db.RegisterMessage(StepValidateRequest)

StepValidateResponse = _reflection.GeneratedProtocolMessageType('StepValidateResponse', (_message.Message,), dict(
  DESCRIPTOR = _STEPVALIDATERESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepValidateResponse)
  ))
_sym_db.RegisterMessage(StepValidateResponse)

SuiteExecutionResult = _reflection.GeneratedProtocolMessageType('SuiteExecutionResult', (_message.Message,), dict(
  DESCRIPTOR = _SUITEEXECUTIONRESULT,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SuiteExecutionResult)
  ))
_sym_db.RegisterMessage(SuiteExecutionResult)

StepNamesRequest = _reflection.GeneratedProtocolMessageType('StepNamesRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPNAMESREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepNamesRequest)
  ))
_sym_db.RegisterMessage(StepNamesRequest)

StepNamesResponse = _reflection.GeneratedProtocolMessageType('StepNamesResponse', (_message.Message,), dict(
  DESCRIPTOR = _STEPNAMESRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepNamesResponse)
  ))
_sym_db.RegisterMessage(StepNamesResponse)

ScenarioDataStoreInitRequest = _reflection.GeneratedProtocolMessageType('ScenarioDataStoreInitRequest', (_message.Message,), dict(
  DESCRIPTOR = _SCENARIODATASTOREINITREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ScenarioDataStoreInitRequest)
  ))
_sym_db.RegisterMessage(ScenarioDataStoreInitRequest)

SpecDataStoreInitRequest = _reflection.GeneratedProtocolMessageType('SpecDataStoreInitRequest', (_message.Message,), dict(
  DESCRIPTOR = _SPECDATASTOREINITREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SpecDataStoreInitRequest)
  ))
_sym_db.RegisterMessage(SpecDataStoreInitRequest)

SuiteDataStoreInitRequest = _reflection.GeneratedProtocolMessageType('SuiteDataStoreInitRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUITEDATASTOREINITREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.SuiteDataStoreInitRequest)
  ))
_sym_db.RegisterMessage(SuiteDataStoreInitRequest)

ParameterPosition = _reflection.GeneratedProtocolMessageType('ParameterPosition', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERPOSITION,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ParameterPosition)
  ))
_sym_db.RegisterMessage(ParameterPosition)

RefactorRequest = _reflection.GeneratedProtocolMessageType('RefactorRequest', (_message.Message,), dict(
  DESCRIPTOR = _REFACTORREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.RefactorRequest)
  ))
_sym_db.RegisterMessage(RefactorRequest)

FileChanges = _reflection.GeneratedProtocolMessageType('FileChanges', (_message.Message,), dict(
  DESCRIPTOR = _FILECHANGES,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.FileChanges)
  ))
_sym_db.RegisterMessage(FileChanges)

RefactorResponse = _reflection.GeneratedProtocolMessageType('RefactorResponse', (_message.Message,), dict(
  DESCRIPTOR = _REFACTORRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.RefactorResponse)
  ))
_sym_db.RegisterMessage(RefactorResponse)

StepNameRequest = _reflection.GeneratedProtocolMessageType('StepNameRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPNAMEREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepNameRequest)
  ))
_sym_db.RegisterMessage(StepNameRequest)

StepNameResponse = _reflection.GeneratedProtocolMessageType('StepNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _STEPNAMERESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepNameResponse)
  ))
_sym_db.RegisterMessage(StepNameResponse)

UnsupportedMessageResponse = _reflection.GeneratedProtocolMessageType('UnsupportedMessageResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSUPPORTEDMESSAGERESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.UnsupportedMessageResponse)
  ))
_sym_db.RegisterMessage(UnsupportedMessageResponse)

CacheFileRequest = _reflection.GeneratedProtocolMessageType('CacheFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _CACHEFILEREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.CacheFileRequest)
  ))
_sym_db.RegisterMessage(CacheFileRequest)

StepPositionsRequest = _reflection.GeneratedProtocolMessageType('StepPositionsRequest', (_message.Message,), dict(
  DESCRIPTOR = _STEPPOSITIONSREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepPositionsRequest)
  ))
_sym_db.RegisterMessage(StepPositionsRequest)

StepPositionsResponse = _reflection.GeneratedProtocolMessageType('StepPositionsResponse', (_message.Message,), dict(

  StepPosition = _reflection.GeneratedProtocolMessageType('StepPosition', (_message.Message,), dict(
    DESCRIPTOR = _STEPPOSITIONSRESPONSE_STEPPOSITION,
    __module__ = 'messages_pb2'
    # @@protoc_insertion_point(class_scope:gauge.messages.StepPositionsResponse.StepPosition)
    ))
  ,
  DESCRIPTOR = _STEPPOSITIONSRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StepPositionsResponse)
  ))
_sym_db.RegisterMessage(StepPositionsResponse)
_sym_db.RegisterMessage(StepPositionsResponse.StepPosition)

ImplementationFileGlobPatternRequest = _reflection.GeneratedProtocolMessageType('ImplementationFileGlobPatternRequest', (_message.Message,), dict(
  DESCRIPTOR = _IMPLEMENTATIONFILEGLOBPATTERNREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ImplementationFileGlobPatternRequest)
  ))
_sym_db.RegisterMessage(ImplementationFileGlobPatternRequest)

ImplementationFileGlobPatternResponse = _reflection.GeneratedProtocolMessageType('ImplementationFileGlobPatternResponse', (_message.Message,), dict(
  DESCRIPTOR = _IMPLEMENTATIONFILEGLOBPATTERNRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ImplementationFileGlobPatternResponse)
  ))
_sym_db.RegisterMessage(ImplementationFileGlobPatternResponse)

ImplementationFileListRequest = _reflection.GeneratedProtocolMessageType('ImplementationFileListRequest', (_message.Message,), dict(
  DESCRIPTOR = _IMPLEMENTATIONFILELISTREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ImplementationFileListRequest)
  ))
_sym_db.RegisterMessage(ImplementationFileListRequest)

ImplementationFileListResponse = _reflection.GeneratedProtocolMessageType('ImplementationFileListResponse', (_message.Message,), dict(
  DESCRIPTOR = _IMPLEMENTATIONFILELISTRESPONSE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.ImplementationFileListResponse)
  ))
_sym_db.RegisterMessage(ImplementationFileListResponse)

StubImplementationCodeRequest = _reflection.GeneratedProtocolMessageType('StubImplementationCodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _STUBIMPLEMENTATIONCODEREQUEST,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.StubImplementationCodeRequest)
  ))
_sym_db.RegisterMessage(StubImplementationCodeRequest)

TextDiff = _reflection.GeneratedProtocolMessageType('TextDiff', (_message.Message,), dict(
  DESCRIPTOR = _TEXTDIFF,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.TextDiff)
  ))
_sym_db.RegisterMessage(TextDiff)

FileDiff = _reflection.GeneratedProtocolMessageType('FileDiff', (_message.Message,), dict(
  DESCRIPTOR = _FILEDIFF,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.FileDiff)
  ))
_sym_db.RegisterMessage(FileDiff)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGE,
  __module__ = 'messages_pb2'
  # @@protoc_insertion_point(class_scope:gauge.messages.Message)
  ))
_sym_db.RegisterMessage(Message)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.thoughtworks.gauge\252\002\016Gauge.Messages'))
_FILECHANGES.fields_by_name['fileContent'].has_options = True
_FILECHANGES.fields_by_name['fileContent']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
# @@protoc_insertion_point(module_scope)
